Changelog for gimli
===================

0.2.1 (2021-03-02)
------------------

- Fixed a bug caused by passing a single value to the cli (#10)

- Added content to the README, mainly installation and usage instructions (#9)

0.2.0b1 (2021-02-22)
--------------------

- Added release and prerelease actions to publish on PyPI and TestPyPI (#8)

- Change name of package to gimli.units (#7)


0.2.0b0 (2021-02-20)
--------------------

- Added gimli command-line interface (#6)

- Better handling of multi-dimensional and non-contiguous arrays (#5)

- Fixed a issue that caused a segmentation fault when using dimensionless units (#4)

0.1.1 (2021-02-17)
------------------

- Created the gimli package (#1)

- Set continuous integration using GitHub actions (#2)

- Deploy to TestPyPI on a version tag (#3)
